@@ -1,8 +1,10 @@
 #!/bin/sh
 # the next line restarts using wish \
-exec wish8.2 "$0" "$@"
+exec wish8.4 "$0" "$@"
 
-package require -exact snack 2.0
+package require -exact snack 2.2
+# Try to load optional file format handler
+catch { package require snackogg }
 
 snack::debug 0
 
@@ -17,8 +19,8 @@ proc Cmd { sock addr port } {
 	    set s [snack::sound -debug 0]
 	    puts $sock $s ;# return token for this job
 	    flush $sock
-	    $s config -channel $sock -guessproperties yes
-	    $s play -command "[list close $sock]; set msg idle;$s destroy"
+	    $s configure -channel $sock -guessproperties yes
+	    $s play -command "close $sock; set msg idle;$s destroy"
 	    set msg playing
 	}
 	stop {
