@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1997-2002 Kare Sjolander <kare@speech.kth.se>
+ * Copyright (C) 1997-2005 Kare Sjolander <kare@speech.kth.se>
  *
  * This file is part of the Snack Sound Toolkit.
  * The latest version can be found at http://www.speech.kth.se/snack/
@@ -739,9 +739,7 @@ ConfigureSection(Tcl_Interp *interp, Tk_Canvas canvas, Tk_Item *itemPtr,
   GC newGC;
   unsigned long mask;
   int doCompute = 0;
-#if defined(MAC) || defined(MAC_OSX_TCL)
-  int i;
-#endif
+  int i, j;
 
   if (argc == 0) return TCL_OK;
 
@@ -751,6 +749,15 @@ ConfigureSection(Tcl_Interp *interp, Tk_Canvas canvas, Tk_Item *itemPtr,
 
   if (sectPtr->debug) Snack_WriteLog("Enter ConfigureSection\n");
 
+  for (i = 0; configSpecs[i].type != TK_CONFIG_END; i++) {
+    for (j = 0; j < argc; j += 2) {
+      if (strncmp(argv[j], configSpecs[i].argvName, strlen(argv[j])) == 0) {
+	configSpecs[i].specFlags |= TK_CONFIG_OPTION_SPECIFIED;
+	break;
+      }
+    }
+  }
+
 #if defined(MAC) || defined(MAC_OSX_TCL)
   for (i = 0; i < argc; i++) {
     if (strncmp(argv[i], "-anchor", strlen(argv[i])) == 0) {
@@ -963,6 +970,10 @@ ConfigureSection(Tcl_Interp *interp, Tk_Canvas canvas, Tk_Item *itemPtr,
     return TCL_ERROR;
   }
   
+  for (i = 0; configSpecs[i].type != TK_CONFIG_END; i++) {
+    configSpecs[i].specFlags &= ~TK_CONFIG_OPTION_SPECIFIED;
+  }
+  
   if (sectPtr->debug) Snack_WriteLog("Exit ConfigureSection\n");
 
   return TCL_OK;
